import matinput as i
import matmul as m
a = int(input('enter number of rows in mat1 '))
b = int(input('enter number of columns in mat1 '))
mat1 = i.getInputMatrix(a, b)
c = int(input('enter number of rows in mat2 '))
d = int(input('enter number of columns in mat2 '))
mat2 = i.getInputMatrix(c, d)
result = m.matrixMultiplication(mat1, mat2)


def getInputMatrix(row,col):
    A=[]
    print('enter numbers row wise')
    for i in range(row):
        a=[]
        for j in range(col):
            a.append(int(input('enter number ')))
        A.append(a)
    for i in range(row):
        for j in range(col):
            print(A[i][j])
    return A


def matrixMultiplication(mat1,mat2):
    mul_result=[]
    for i in range(len(mat1)):
        sub_list=[]
        for j in range(len(mat2[0])):
            result=0
            for k in range(len(mat2)):
                result = result + mat1[i][k]*mat2[k][j]
            sub_list.append(result)
        mul_result.append(sub_list)
    print(mul_result)
    return mul_result


from setuptools import setup

setup(name='matmul',
      version='0.0.2',
      include_package_data=True,
      description='Matrix Multiplication for 2 matrices',
      author='Dhruv Gupta',
      license = "MIT",
      packages=['matmul'],
      zip_safe=False)
